<img height="60px" width="60px" style="float: left;" src="/assets/img/logo/white.svg" alt="Vex Logo">
<h2 style="height: 60px; line-height: 60px; margin-left: 70px; font-weight: 500; border: none;">VEX</h2>

# Changelog

## 8.4.0 (2019-11-18)

### Features
- Add CustomLayoutComponent to easily create your own custom layout component and customize the template even easier
- If needed, you can now enable strictFunctionTypes & noImplicitReturns in your tsconfig.json
- Add more customization options using NavigationService (Change title & logo in sidenav)
- Add example config with customized completely customized layout and custom title & logo

## 8.3.0 (2019-10-22)

### Features

- Add global search (click on the search button in toolbar)
- Add WYSIWYG Editor
- Add more custom columns to All-In-One Table

### Fixes
- Improve dark mode styles, especially color usage is using opacity now
- Contact Table is now fully responsive
- General style improvements

## 8.2.0 (2019-10-07)

### Features
- Add Typings for TailwindCSS, use TailwindCSS configuration inside your Angular application - 1 Configuration file!

### Fixes
- Fix minor issue on mobile devices, dashboard was overflowing and forced a horizontal scroll on some devices

## 8.1.0 (2019-10-02)

### Features
- Add PurgeCSS to improve build size even more

### Fixed
- Fix minor issue with styles and build

## 8.0.0 (2019-09-19)

### Features
- Added 15 design variations (5 layouts with 3 different styles per layout)
- Allow Top Navigation to have direct links instead of only dropdowns
- Add TailwindCSS for easy customization of Utility CSS

### Fixes
- Optimize Paddings/Margins
- Optimize RTL
- Optimize Styling for Layouts

## 1.0.0 (2019-08-22)

### Features
- Initial release
